# frozen_string_literal: true

module Binance
  class Error < StandardError; end

  # Client error from 400 - 499
  class ClientError < Error
    attr_reader :response

    def initialize(response = nil)
      @response = response
      super(response)
    end
  end

  # Server side error for 5xx
  class ServerError < Error
    def initialize(err)
      super(err)
    end
  end

  # Error when missing required params
  class RequiredParams < Error
    def initialize(param_name, param_value)
      super(
          "ValidationFailed: #{param_name} is required, but provided value: #{param_value}"
      )
    end
  end
end
