# frozen_string_literal: true

require 'binance/session'
require 'binance/authentication'
require 'binance/utils/validation'
require 'binance/utils/url'
require 'binance/error'
require 'binance/spot/market'
require 'binance/spot/trade'

module Binance
  # Spot class will have all modules, includes
  # - Spot
  # - Margin (Waiting)
  # - Wallet (Waiting)
  # - Saving (Waiting)
  # - Mining (Waiting)
  # - etc
  # @see https://binance-docs.github.io/apidocs/spot/en/
  class Spot
    include Binance::Spot::Market
    include Binance::Spot::Trade

    def initialize(key: '', secret: '', **kwargs)
      @session = Session.new kwargs.merge(key: key, secret: secret)
    end
  end
end
